<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="config_dialog.ui" line="32"/>
        <source>Mozc Settings</source>
        <translation>Mozc プロパティ</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="57"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="92"/>
        <source>Input mode</source>
        <translation>ローマ字入力・かな入力</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="99"/>
        <source>Punctuation style</source>
        <translation>句読点</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="106"/>
        <source>Symbol style</source>
        <translation>記号</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="113"/>
        <source>Space input style</source>
        <translation>スペースの入力</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="123"/>
        <source>Selection shortcut</source>
        <translation>候補選択ショートカット</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="130"/>
        <source>Numpad style</source>
        <translation>テンキーからの入力</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="172"/>
        <source>Keymap style</source>
        <translation>キー設定の選択</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="185"/>
        <location filename="config_dialog.ui" line="192"/>
        <source>Customize...</source>
        <translation>編集...</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="218"/>
        <source>Basics</source>
        <translation>基本設定</translation>
    </message>
    <message utf8="true">
        <location filename="config_dialog.ui" line="147"/>
        <source>character entered by ¥ key</source>
        <translation>¥キーで入力する文字</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="998"/>
        <source>Privacy</source>
        <translation>プライバシー</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="250"/>
        <source>Keymap</source>
        <translation>キー設定</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1213"/>
        <source>Cloud</source>
        <translation>クラウド</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="272"/>
        <source>Dictionary</source>
        <translation>辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="287"/>
        <source>Clear personalization data</source>
        <translation>学習履歴のクリア</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="294"/>
        <source>Adjust conversion based on previous input</source>
        <translation>学習機能</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="383"/>
        <source>Single kanji conversion</source>
        <translation>単漢字変換</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="390"/>
        <source>Symbol conversion</source>
        <translation>記号変換</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="439"/>
        <source>Date/time conversion</source>
        <translation>日付変換</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="432"/>
        <source>Special number conversion</source>
        <translation>特殊数字変換</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="425"/>
        <source>Calculator</source>
        <translation>計算機機能</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="418"/>
        <source>Spelling correction</source>
        <translation>「もしかして」変換</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="529"/>
        <source>Special conversions</source>
        <translation>特殊変換</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="561"/>
        <source>Usage dictionary</source>
        <translation>用例辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="593"/>
        <source>Homonym dictionary</source>
        <translation>同音異義語辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="615"/>
        <source>Advanced</source>
        <translation>入力補助</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="704"/>
        <source>Automatically switch to halfwidth</source>
        <translation>自動英数変換を有効にする</translation>
    </message>
    <message utf8="true">
        <location filename="config_dialog.ui" line="734"/>
        <source>、</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="747"/>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="754"/>
        <source>Convert at punctuations</source>
        <translation>句読点変換を有効にする</translation>
    </message>
    <message utf8="true">
        <location filename="config_dialog.ui" line="767"/>
        <source>。</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="780"/>
        <source>!</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="790"/>
        <source>Always use Ja keyboard layout for Japanese input</source>
        <translation>日本語入力では常に日本語キー配列を使う</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="824"/>
        <source>Source data</source>
        <translation>サジェストの種類</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="856"/>
        <source>Other settings</source>
        <translation>その他の設定</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="923"/>
        <source>Use input history</source>
        <translation>入力履歴からのサジェスト自動表示を有効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="943"/>
        <source>Use system dictionary</source>
        <translation>システム辞書からのサジェスト自動表示を有効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="364"/>
        <source>Edit user dictionary...</source>
        <translation>ユーザ辞書の編集...</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="199"/>
        <source>Romaji table</source>
        <translation>ローマ字テーブル</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="397"/>
        <source>Emoticon conversion</source>
        <translation>顔文字変換</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="404"/>
        <source>Katakana to English conversion</source>
        <translation>カタカナ英語変換</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="411"/>
        <source>Zip code conversion</source>
        <translation>郵便番号変換</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="446"/>
        <source>Emoji conversion</source>
        <translation>Unicode 6 絵文字変換</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="465"/>
        <source>Personalization</source>
        <translation>学習</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="497"/>
        <source>User dictionary</source>
        <translation>ユーザー辞書</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="640"/>
        <source>Input Assistance</source>
        <translation>入力補助</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="672"/>
        <source>Fullwidth/Halfwidth</source>
        <translation>半角・全角</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="711"/>
        <source>Shift key mode switch</source>
        <translation>シフトキーでの入力切替</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="800"/>
        <source>Show input mode indicator near the cursor</source>
        <translation>カーソル周辺に入力モードを表示する</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="809"/>
        <source>Suggest</source>
        <translation>サジェスト</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="888"/>
        <source>Maximum number of suggestions</source>
        <translation>サジェストの最大候補数</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="936"/>
        <source>Clear all history</source>
        <translation>全入力履歴を削除</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="956"/>
        <source>Clear unused history</source>
        <translation>未使用の履歴を削除</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="989"/>
        <source>Use realtime conversion</source>
        <translation>リアルタイム変換を有効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1083"/>
        <source>Secret mode</source>
        <translation>シークレットモード</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1134"/>
        <source>Temporarily disable conversion personalization, history-based suggestions and user dictionary</source>
        <translation>一時的に学習機能、入力履歴からのサジェスト機能、ユーザ辞書機能を無効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1175"/>
        <source>Temporarily disable all suggestions</source>
        <translation>一時的にすべてのサジェスト機能を無効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1191"/>
        <source>Presentation mode</source>
        <translation>プレゼンテーションモード</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1241"/>
        <source>Cloud handwriting recognition</source>
        <translation>クラウド手書き文字認識</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1263"/>
        <source>Misc</source>
        <translation>その他</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1563"/>
        <source>Startup</source>
        <translation>スタートアップ</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1601"/>
        <source>Start conversion engine on login</source>
        <translation>ログイン時に変換エンジンプログラムを起動する</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1694"/>
        <source>Logging level (debug only)</source>
        <translation>ログレベル（デバッグ）</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1650"/>
        <source>Logging</source>
        <translation>ログ</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1447"/>
        <source>Administration</source>
        <translation>管理</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1162"/>
        <location filename="config_dialog.ui" line="1504"/>
        <source>Settings...</source>
        <translation>設定変更...</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1491"/>
        <source>Dictionary preloading and UAC settings</source>
        <translation>オンメモリ辞書とUACの設定</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1051"/>
        <source>Usage statistics and crash reports</source>
        <translation>使用統計情報と障害レポート</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1032"/>
        <source>Help make Mozc better by automatically sending usage statistics and crash reports to Google (changes will take effect after you log out and log back in)</source>
        <translation>使用統計データや障害レポートを Google に自動送信して
Mozcの機能向上に役立てる（再ログイン後に変更は完了します）</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1225"/>
        <source>Enable Cloud handwriting recognition</source>
        <translation>クラウド手書き文字認識を有効にする</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1385"/>
        <source>Check if Mozc is the default IME on startup</source>
        <translation>起動時に Mozcが既定の IME であるか確認する</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1395"/>
        <source>Disable Keyboard layout hotkey (Ctrl+Shift)</source>
        <translation>ホットキー(Ctrl+Shift)による IME の切り替えを無効化する</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1338"/>
        <source>Default IME</source>
        <translation>既定の IME</translation>
    </message>
    <message>
        <location filename="config_dialog.ui" line="1775"/>
        <source>Reset to defaults</source>
        <translation>初期値に戻す</translation>
    </message>
</context>
<context>
    <name>GenericTableEditorDialog</name>
    <message>
        <location filename="generic_table_editor.ui" line="14"/>
        <source>Mozc</source>
        <translation>Mozc</translation>
    </message>
    <message>
        <location filename="generic_table_editor.ui" line="62"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
</context>
<context>
    <name>KeyBindingEditor</name>
    <message>
        <location filename="keybinding_editor.ui" line="32"/>
        <source>Mozc key binding editor</source>
        <translation>Mozc キーバインディング 設定</translation>
    </message>
    <message>
        <location filename="keybinding_editor.ui" line="92"/>
        <source>Input key assignments:</source>
        <translation>割り当てるキーの入力:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="character_form_editor.cc" line="15"/>
        <location filename="character_form_editor.cc" line="30"/>
        <source>Fullwidth</source>
        <translation>全角</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="18"/>
        <location filename="character_form_editor.cc" line="32"/>
        <source>Halfwidth</source>
        <translation>半角</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="21"/>
        <location filename="character_form_editor.cc" line="34"/>
        <source>Remember</source>
        <translation>学習</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="24"/>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="43"/>
        <location filename="character_form_editor.cc" line="53"/>
        <location filename="character_form_editor.cc" line="123"/>
        <source>Katakana</source>
        <translation>カタカナ</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="45"/>
        <location filename="character_form_editor.cc" line="56"/>
        <source>Numbers</source>
        <translation>数字</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="47"/>
        <location filename="character_form_editor.cc" line="58"/>
        <source>Alphabets</source>
        <translation>アルファベット</translation>
    </message>
</context>
<context>
    <name>mozc::gui::CharacterFormEditor</name>
    <message>
        <location filename="character_form_editor.cc" line="68"/>
        <source>Fullwidth</source>
        <translation>全角</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="68"/>
        <source>Halfwidth</source>
        <translation>半角</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="68"/>
        <source>Remember</source>
        <translation>学習</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="72"/>
        <source>Character form editor</source>
        <translation>半角・全角設定</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="90"/>
        <source>Group</source>
        <translation>文字グループ</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="90"/>
        <source>Composition</source>
        <translation>変換前文字列</translation>
    </message>
    <message>
        <location filename="character_form_editor.cc" line="90"/>
        <source>Conversion</source>
        <translation>変換中文字列</translation>
    </message>
</context>
<context>
    <name>mozc::gui::ConfigDialog</name>
    <message>
        <location filename="config_dialog.cc" line="127"/>
        <source>Kotoeri</source>
        <translation>ことえり</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="124"/>
        <source>Custom keymap</source>
        <translation>カスタム</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="68"/>
        <source>Mozc Preferences</source>
        <translation>Mozc 環境設定</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="125"/>
        <source>ATOK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="126"/>
        <source>MS-IME</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="133"/>
        <source>Romaji</source>
        <translation>ローマ字入力</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="134"/>
        <source>Kana</source>
        <translation>かな入力</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="138"/>
        <source>Romaji (switchable)</source>
        <translation>ローマ字入力 (切替可)</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="139"/>
        <source>Kana (switchable)</source>
        <translation>かな入力 (切替可)</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="142"/>
        <location filename="config_dialog.cc" line="158"/>
        <source>Follow input mode</source>
        <translation>入力モードに従う</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="143"/>
        <location filename="config_dialog.cc" line="159"/>
        <source>Fullwidth</source>
        <translation>全角</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="144"/>
        <location filename="config_dialog.cc" line="160"/>
        <source>Halfwidth</source>
        <translation>半角</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="146"/>
        <source>No shortcut</source>
        <translation>なし</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="147"/>
        <source>1 -- 9</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="148"/>
        <source>A -- L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="150"/>
        <source>Yes</source>
        <translation>有効</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="151"/>
        <source>Yes (don&apos;t record new data)</source>
        <translation>有効（新規学習はしない）</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="152"/>
        <source>No</source>
        <translation>無効</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="154"/>
        <source>Off</source>
        <translation>オフ</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="155"/>
        <source>Alphanumeric</source>
        <translation>英数字</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="156"/>
        <source>Katakana</source>
        <translation>カタカナ</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="161"/>
        <source>Direct input</source>
        <translation>直接入力</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="163"/>
        <source>0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="164"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="165"/>
        <source>2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="167"/>
        <source>Yen Sign Â¥</source>
        <translation>円記号(¥)</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="168"/>
        <source>Backslash \</source>
        <translation>バックスラッシュ(\)</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="360"/>
        <source>Failed to get current config values.</source>
        <translation>設定の取得に失敗しました。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="392"/>
        <source>Romaji/Kana setting is enabled from new applications.</source>
        <translation>ローマ字・かな入力の設定は新しいアプリケーションから有効になります。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="403"/>
        <source>Input mode indicator setting is enabled from new applications.</source>
        <translation>入力モード表示の設定は新しいアプリケーションから有効になります。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="736"/>
        <location filename="config_dialog.cc" line="758"/>
        <source>Mozc Converter is not running. Settings were not saved.</source>
        <translation>変換サーバが反応していません。設定の反映に失敗しました。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="853"/>
        <source>When you reset Mozc settings, any changes you&apos;ve made will be reverted to the default settings. Do you want to reset settings? The following items are not reset with this operation.
 - Personalization data
 - Input history
 - Usage statistics and crash reports
 - Administrator settings</source>
        <translation>この機能を実行すると Mozcの設定が標準状態に戻ります。実行しますか？ 以下の設定はリセットされません。
 - 学習履歴
 - 入力履歴
 - 使用統計と障害レポート
 - 管理者用設定</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="283"/>
        <source>Dictionary preloading</source>
        <translation>オンメモリ辞書の設定</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="379"/>
        <source>The current custom keymap table is empty. When custom keymap is selected, you must customize it.</source>
        <translation>有効なキー設定がありません。カスタム キーマップを選択した場合は、キーマップを編集する必要があります。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="411"/>
        <source>Failed to update config</source>
        <translation>設定の反映に失敗しました</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="722"/>
        <source>Do you want to clear personalization data? Input history is not reset with this operation. Please open &quot;suggestion&quot; tab to remove input history data.</source>
        <translation>学習結果がリセットされます。実行しますか？ 入力履歴データはリセットされません。入力履歴データのリセットは「サジェスト→全入力履歴の削除」で行えます。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="780"/>
        <source>Mozc Converter is not running. Operation was not executed.</source>
        <translation>Mozcコンバーターが起動していません。設定の反映に失敗しました。</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="746"/>
        <source>Do you want to clear all history data?</source>
        <translation>すべての入力履歴が削除されます。実行しますか？</translation>
    </message>
    <message>
        <location filename="config_dialog.cc" line="768"/>
        <source>Do you want to clear unused history data?</source>
        <translation>サジェスト経由で入力されなかった履歴が削除されます。実行しますか？</translation>
    </message>
</context>
<context>
    <name>mozc::gui::GenericTableEditorDialog</name>
    <message>
        <location filename="generic_table_editor.cc" line="59"/>
        <source>Edit</source>
        <translation>編集</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="136"/>
        <location filename="generic_table_editor.cc" line="202"/>
        <source>No entry is selected</source>
        <translation>エントリーが選択されていません</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="213"/>
        <source>You can&apos;t have more than %1 entries</source>
        <translation>%1 個以上のエントリーは登録できません</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="222"/>
        <source>import from file</source>
        <translation>インポート</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="232"/>
        <source>File not found</source>
        <translation>ファイルが見つかりません</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="240"/>
        <source>The specified file is too large (&gt;=100K byte)</source>
        <translation>ファイルサイズが大きすぎて読み込めません</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="248"/>
        <source>Import failed</source>
        <translation>インポートに失敗しました</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="259"/>
        <source>export to file</source>
        <translation>エクスポート</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="270"/>
        <source>Export failed</source>
        <translation>エクスポートに失敗しました</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="307"/>
        <source>Edit entry</source>
        <translation>エントリーを編集</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="309"/>
        <source>New entry</source>
        <translation>エントリーを追加</translation>
    </message>
    <message>
        <location filename="generic_table_editor.cc" line="310"/>
        <source>Remove entry</source>
        <translation>エントリーを削除</translation>
    </message>
</context>
<context>
    <name>mozc::gui::KeyMapEditorDialog</name>
    <message>
        <location filename="keymap_editor.cc" line="223"/>
        <source>New entry</source>
        <translation>エントリーを追加</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="225"/>
        <source>Remove selected entries</source>
        <translation>選択されたエントリーを削除</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="229"/>
        <source>Import predefined mapping</source>
        <translation>定義済みのキーマップからインポート</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="233"/>
        <source>ATOK</source>
        <translation></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="234"/>
        <source>MS-IME</source>
        <translation></translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="235"/>
        <source>Kotoeri</source>
        <translation>ことえり</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="239"/>
        <source>Import from file...</source>
        <translation>インポート...</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="241"/>
        <source>Export to file...</source>
        <translation>エクスポート...</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="282"/>
        <source>Mozc keymap editor</source>
        <translation>Mozc キー設定</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="286"/>
        <source>Mode</source>
        <translation>モード</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="286"/>
        <source>Key</source>
        <translation>入力キー</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="286"/>
        <source>Command</source>
        <translation>コマンド</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="371"/>
        <source>Current keymap table is empty. You might want to import a pre-defined keymap table first.</source>
        <translation>有効なキーマップがありません。定義済みのキーマップをインポートするか、有効なキーマップを追加してください。</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="411"/>
        <source>Invalid key:
%1</source>
        <translation>無効な入力キーです:
%1</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="430"/>
        <source>The keymaps for IME ON and Reconversion will be applied after new applications.</source>
        <translation>IME の有効化と再変換に対するキー設定は、新しいアプリケーションから有効になります。</translation>
    </message>
    <message>
        <location filename="keymap_editor.cc" line="466"/>
        <source>Do you want to overwrite the current keymaps?</source>
        <translation>現在のキー設定が上書きされます。実行しますか？</translation>
    </message>
</context>
<context>
    <name>mozc::gui::RomanTableEditorDialog</name>
    <message>
        <location filename="roman_table_editor.cc" line="33"/>
        <source>New entry</source>
        <translation>新しいエントリー</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="35"/>
        <source>Remove selected entries</source>
        <translation>選択されたエントリーを削除</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="38"/>
        <source>Import from file...</source>
        <translation>インポート...</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="40"/>
        <source>Export to file...</source>
        <translation>エクスポート...</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="43"/>
        <source>Reset to defaults</source>
        <translation>初期値に戻す</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="45"/>
        <source>Mozc Romaji table editor</source>
        <translation>Mozcローマ字テーブル設定</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="49"/>
        <source>Input</source>
        <translation>入力</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="49"/>
        <source>Output</source>
        <translation>出力</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="49"/>
        <source>Next input</source>
        <translation>次の入力</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="128"/>
        <location filename="roman_table_editor.cc" line="149"/>
        <location filename="roman_table_editor.cc" line="189"/>
        <location filename="roman_table_editor.cc" line="216"/>
        <source>Mozc settings</source>
        <translation>Mozcプロパティ</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="129"/>
        <source>You can&apos;t have more than %1 entries</source>
        <translation>%1 個以上のエントリーは登録できません</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="150"/>
        <source>Romaji to Kana table is empty.</source>
        <translation>ローマ字テーブルが空です</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="190"/>
        <source>Input fields contain capital characters. &quot;Shift-mode-switch&quot; function is disabled with this new mapping.</source>
        <translation>入力フィールドに大文字のアルファベットが含まれています。新しい設定では「シフトキーによる入力切替」は無効になります。</translation>
    </message>
    <message>
        <location filename="roman_table_editor.cc" line="217"/>
        <source>Do you want to overwrite the current roman table?</source>
        <translation>現在のローマ字テーブルを上書きしますか？</translation>
    </message>
</context>
</TS>
